@@ -12,4 +12,5 @@ Copyright © Semantyk 2021. All rights reserved.\
 
 
 def test_import():
-    import semantyk
+    # Import Declaration | semanytk
+    from src import semantyk
